summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TTextBox.php
diff options
context:
space:
mode:
Diffstat (limited to 'framework/Web/UI/WebControls/TTextBox.php')
-rw-r--r--framework/Web/UI/WebControls/TTextBox.php15
1 files changed, 9 insertions, 6 deletions
diff --git a/framework/Web/UI/WebControls/TTextBox.php b/framework/Web/UI/WebControls/TTextBox.php
index 05495543..14a333e8 100644
--- a/framework/Web/UI/WebControls/TTextBox.php
+++ b/framework/Web/UI/WebControls/TTextBox.php
@@ -10,6 +10,9 @@
*/
namespace Prado\Web\UI\WebControls;
+use Prado\TPropertyValue;
+use Prado\Web\THttpUtility;
+use Prado\Exceptions\TInvalidDataValueException;
/**
* TTextBox class
@@ -48,7 +51,7 @@ namespace Prado\Web\UI\WebControls;
* @package Prado\Web\UI\WebControls
* @since 3.0
*/
-class TTextBox extends TWebControl implements IPostBackDataHandler, IValidatable, IDataRenderer
+class TTextBox extends \Prado\Web\UI\WebControls\TWebControl implements \Prado\Web\UI\IPostBackDataHandler, \Prado\Web\UI\IValidatable, \Prado\IDataRenderer
{
/**
* Default number of rows (for MultiLine text box)
@@ -228,7 +231,7 @@ class TTextBox extends TWebControl implements IPostBackDataHandler, IValidatable
/**
* Returns a value indicating whether postback has caused the control data change.
* This method is required by the IPostBackDataHandler interface.
* @return boolean whether postback has caused the control data change. False if the page is not in postback mode.
*/
public function getDataChanged()
@@ -238,7 +241,7 @@ class TTextBox extends TWebControl implements IPostBackDataHandler, IValidatable
/**
* Returns the value to be validated.
* This methid is required by IValidatable interface.
* @return mixed the value of the property to be validated.
*/
public function getValidationPropertyValue()
@@ -278,7 +281,7 @@ class TTextBox extends TWebControl implements IPostBackDataHandler, IValidatable
/**
* Raises postdata changed event.
* This method is required by {@link IPostBackDataHandler} interface.
* It is invoked by the framework when {@link getText Text} property
* is changed on postback.
* This method is primarly used by framework developers.
@@ -486,7 +489,7 @@ class TTextBox extends TWebControl implements IPostBackDataHandler, IValidatable
/**
* Returns the text content of the TTextBox control.
* This method is required by {@link IDataRenderer}.
* It is the same as {@link getText()}.
* @return string the text content of the TTextBox control.
* @see getText
@@ -499,7 +502,7 @@ class TTextBox extends TWebControl implements IPostBackDataHandler, IValidatable
/**
* Sets the text content of the TTextBox control.
* This method is required by {@link IDataRenderer}.
* It is the same as {@link setText()}.
* @param string the text content of the TTextBox control.
* @see setText
@@ -228,7 +231,7 @@ class TTextBox extends TWebControl implements IPostBackDataHandler, IValidatable
/**
* Returns a value indicating whether postback has caused the control data change.
- * This method is required by the IPostBackDataHandler interface.
+ * This method is required by the \Prado\Web\UI\IPostBackDataHandler interface.
* @return boolean whether postback has caused the control data change. False if the page is not in postback mode.
*/
@@ -238,7 +241,7 @@ class TTextBox extends TWebControl implements IPostBackDataHandler, IValidatable
/**
* Returns the value to be validated.
- * This methid is required by IValidatable interface.
+ * This methid is required by \Prado\Web\UI\IValidatable interface.
* @return mixed the value of the property to be validated.
*/
@@ -278,7 +281,7 @@ class TTextBox extends TWebControl implements IPostBackDataHandler, IValidatable
/**
* Raises postdata changed event.
- * This method is required by {@link IPostBackDataHandler} interface.
+ * This method is required by {@link \Prado\Web\UI\IPostBackDataHandler} interface.
* It is invoked by the framework when {@link getText Text} property
* is changed on postback.
@@ -486,7 +489,7 @@ class TTextBox extends TWebControl implements IPostBackDataHandler, IValidatable
/**
* Returns the text content of the TTextBox control.
- * This method is required by {@link IDataRenderer}.
+ * This method is required by {@link \Prado\IDataRenderer}.
* It is the same as {@link getText()}.
* @return string the text content of the TTextBox control.
@@ -499,7 +502,7 @@ class TTextBox extends TWebControl implements IPostBackDataHandler, IValidatable
/**
* Sets the text content of the TTextBox control.
- * This method is required by {@link IDataRenderer}.
+ * This method is required by {@link \Prado\IDataRenderer}.
* It is the same as {@link setText()}.
* @param string the text content of the TTextBox control.